@@ -4,14 +4,11 @@
 #ifndef DOCUMENTHANDLER_H
 #define DOCUMENTHANDLER_H
 
-#define protected public
 #include <QQuickItem>
-#undef protected
 
 #include "nestedlisthelper_p.h"
 #include <QFont>
 #include <QObject>
-#include <QQmlEngine>
 #include <QQuickTextDocument>
 #include <QTextCursor>
 #include <QUrl>
@@ -119,6 +116,8 @@ public:
     Q_INVOKABLE QString currentLinkText() const;
     Q_INVOKABLE void updateLink(const QString &linkUrl, const QString &linkText);
     Q_INVOKABLE void insertImage(const QUrl &imagePath);
+    Q_INVOKABLE void insertTable(int rows, int columns);
+    Q_INVOKABLE void slotKeyPressed(int key);
 
 public Q_SLOTS:
     void load(const QUrl &fileUrl);
@@ -165,6 +164,8 @@ Q_SIGNALS:
     void cut();
     void undo();
     void redo();
+    void moveCursor(int position);
+    void selectCursor(int start, int end);
 
 protected:
     bool eventFilter(QObject *object, QEvent *event) override;
@@ -176,9 +177,11 @@ private:
     QTextDocument *textDocument() const;
     void mergeFormatOnWordOrSelection(const QTextCharFormat &format);
     QColor linkColor();
-    void evaluateReturnKeySupport(QKeyEvent *event);
-    void evaluateListSupport(QKeyEvent *event);
+    bool evaluateReturnKeySupport(QKeyEvent *event);
+    bool evaluateListSupport(QKeyEvent *event);
     bool handleShortcut(QKeyEvent *event);
+    /// @returns whether the event should be handled by the normal TextEdit
+    /// keyPressed event handler
     bool processKeyEvent(QKeyEvent *event);
     void moveLineUpDown(bool moveUp);
     void moveCursorBeginUpDown(bool moveUp);
@@ -206,6 +209,7 @@ private:
     QFont m_font;
     QUrl m_fileUrl;
     NestedListHelper m_nestedListHelper;
+    QString m_frontMatter;
 };
 
 #endif // DOCUMENTHANDLER_H
